@@ -22,6 +22,7 @@
 #include <Lum/Base/String.h>
 
 #include <Lum/Combo.h>
+#include <Lum/Dialog.h>
 #include <Lum/Label.h>
 #include <Lum/String.h>
 #include <Lum/Text.h>
@@ -56,17 +57,17 @@ public:
 
   void PreInit()
   {
-    Lum::Combo                        *combo;
-    Lum::Label                        *label;
-    Lum::Panel                        *panel;
-    Lum::String                       *string;
-    Lum::Text                         *text;
-    Lum::TextValue                    *textValue;
-    Lum::Wizard                       *wizard;
+    Lum::Object                *oneOfMany;
+    Lum::Label                 *label;
+    Lum::Panel                 *panel;
+    Lum::String                *string;
+    Lum::Text                  *text;
+    Lum::TextValue             *textValue;
+    Lum::Wizard                *wizard;
 
-    Lum::Model::ActionRef             stepAction;
-    Lum::Model::StringTableRef        resUnitList;
-    Unit                              *unit;
+    Lum::Model::ActionRef      stepAction;
+    Lum::Model::StringTableRef resUnitList;
+    Unit                       *unit;
 
     wizard=new Lum::Wizard();
     wizard->SetCancelAction(GetClosedAction());
@@ -93,11 +94,12 @@ public:
       resUnitList->Append(unit->GetAlternative(j)->GetName());
     }
 
-    combo=new Lum::IndexCombo();
-    combo->SetFlex(true,false);
-    combo->SetModel(resUnit);
-    combo->SetTableModel(resUnitList);
-    label->AddLabel(L"Unit:",combo);
+    Lum::Def::OneOfMany resUnitDef(Lum::Def::Desc(L"Unit"),
+                                resUnit,resUnitList);
+
+    oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(resUnitDef);
+    oneOfMany->SetFlex(true,false);
+    label->AddLabel(L"Unit:",oneOfMany);
 
     panel->Add(label);
 
@@ -135,11 +137,12 @@ public:
       string->SetModel(value);
       label->AddLabel(L"Value:",string);
 
-      combo=new Lum::IndexCombo();
-      combo->SetFlex(true,false);
-      combo->SetModel(srcUnit);
-      combo->SetTableModel(srcUnitList);
-      label->AddLabel(L"Unit:",combo);
+      Lum::Def::OneOfMany srcUnitDef(Lum::Def::Desc(L"Unit"),
+                                     srcUnit,srcUnitList);
+
+      oneOfMany=Lum::OS::display->GetBehaviour()->GetOneOfManyControl(resUnitDef);
+      oneOfMany->SetFlex(true,false);
+      label->AddLabel(L"Unit:",oneOfMany);
 
       panel->Add(label);
 
